# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["ContextEnum"]

ContextEnum: TypeAlias = Literal["https://schema.org/", "http://schema.org/", "https://schema.org", "http://schema.org"]
